@@ -6,11 +6,8 @@ from functools import cached_property
 from typing import Any, Dict, List, Optional, Union
 
 import stringcase
-from datamodel_code_generator import (
-    DataModelField,
-    load_json_or_yaml,
-    snooper_to_methods,
-)
+import yaml
+from datamodel_code_generator import DataModelField, snooper_to_methods
 from datamodel_code_generator.imports import IMPORT_LIST, Import, Imports
 from datamodel_code_generator.model.pydantic.types import type_map
 from datamodel_code_generator.parser.jsonschema import (
@@ -76,7 +73,7 @@ class Argument(CachedPropertyModel):
 
     @cached_property
     def argument(self) -> str:
-        if not self.default and self.required:
+        if self.default is None and self.required:
             return f'{self.name}: {self.type_hint}'
         return f'{self.name}: {self.type_hint} = {self.default}'
 
@@ -89,6 +86,7 @@ class Operation(CachedPropertyModel):
     responses: Dict[UsefulStr, Any] = {}
     requestBody: Dict[str, Any] = {}
     imports: List[Import] = []
+    security: Optional[List[Dict[str, List[str]]]] = None
 
     @cached_property
     def root_path(self) -> UsefulStr:
@@ -168,7 +166,8 @@ class Operation(CachedPropertyModel):
         if self.operationId:
             name: str = self.operationId
         else:
-            name = f"{self.type}{re.sub(r'[/{}]', '_', self.path)}"
+            path = re.sub(r'/{|/', '_', self.snake_case_path).replace('}', '')
+            name = f"{self.type}{path}"
         return stringcase.snakecase(name)
 
     @cached_property
@@ -216,17 +215,18 @@ class Operation(CachedPropertyModel):
             required=parameter.get("required") or parameter.get("in") == "path",
         )
         self.imports.extend(field.imports)
-        represented_default = repr(schema.default)
         if orig_name != name:
-            default = f"Query({'...' if field.required else represented_default}, alias='{orig_name}')"
+            default: Optional[
+                str
+            ] = f"Query({'...' if field.required else repr(schema.default)}, alias='{orig_name}')"
             self.imports.append(Import(from_='fastapi', import_='Query'))
         else:
-            default = represented_default
+            default = repr(schema.default) if 'default' in parameter["schema"] else None
         return Argument(
             name=field.name,
             type_hint=field.type_hint,
             default=default,  # type: ignore
-            default_value=represented_default,  # type: ignore
+            default_value=schema.default,
             required=field.required,
         )
 
@@ -297,6 +297,7 @@ class Operations(BaseModel):
     options: Optional[Operation] = None
     trace: Optional[Operation] = None
     path: UsefulStr
+    security: Optional[List[Dict[str, List[str]]]] = []
 
     @root_validator(pre=True)
     def inject_path_and_type_to_operation(cls, values: Dict[str, Any]) -> Any:
@@ -309,20 +310,26 @@ class Operations(BaseModel):
             },
             path=path,
             parameters=values.get('parameters', []),
+            security=values.get('security'),
         )
 
     @root_validator
-    def inject_parameters_to_operation(cls, values: Dict[str, Any]) -> Any:
-        if parameters := values.get('parameters'):
-            for operation_name in OPERATION_NAMES:
-                if operation := values.get(operation_name):
+    def inject_parameters_and_security_to_operation(cls, values: Dict[str, Any]) -> Any:
+        security = values.get('security')
+        for operation_name in OPERATION_NAMES:
+            if operation := values.get(operation_name):
+                if parameters := values.get('parameters'):
                     operation.parameters.extend(parameters)
+                if security is not None and operation.security is None:
+                    operation.security = security
+
         return values
 
 
 class Path(CachedPropertyModel):
     path: UsefulStr
     operations: Optional[Operations] = None
+    security: Optional[List[Dict[str, List[str]]]] = []
 
     @root_validator(pre=True)
     def validate_root(cls, values: Dict[str, Any]) -> Any:
@@ -330,9 +337,13 @@ class Path(CachedPropertyModel):
             if isinstance(path, str):
                 if operations := values.get('operations'):
                     if isinstance(operations, dict):
+                        security = values.get('security', [])
                         return {
                             'path': path,
-                            'operations': dict(**operations, path=path),
+                            'operations': dict(
+                                **operations, path=path, security=security
+                            ),
+                            'security': security,
                         }
         return values
 
@@ -376,16 +387,22 @@ class OpenAPIParser:
             model_path_var.set(model_path)
 
     def parse(self) -> ParsedObject:
-        openapi = load_json_or_yaml(self.input_text)
-        return self.parse_paths(openapi["paths"])
+        openapi = yaml.safe_load(self.input_text)
+        return self.parse_paths(openapi)
 
-    def parse_paths(self, paths: Dict[str, Any]) -> ParsedObject:
+    def parse_security(
+        self, openapi: Dict[str, Any]
+    ) -> Optional[List[Dict[str, List[str]]]]:
+        return openapi.get('security')
+
+    def parse_paths(self, openapi: Dict[str, Any]) -> ParsedObject:
+        security = self.parse_security(openapi)
         return ParsedObject(
             [
                 operation
-                for path_name, operations in paths.items()
+                for path_name, operations in openapi['paths'].items()
                 for operation in Path(
-                    path=UsefulStr(path_name), operations=operations
+                    path=UsefulStr(path_name), operations=operations, security=security
                 ).exists_operations
             ]
         )
